A two-column data set of the American Community Survey variable names and their descriptions. Contains counts of various subdivisions of the population based on age, sex, race, and ethnicity.
acs_age_sex_race_ethnicity_varsA tibble with 65 rows and 2 variables:
ACS variable name
A description of who is present in the count
These variable names have been consistent throughout the existence of the ACS from its beginning through 2020.
This data set is used to support synthetic_population().
decennial_age_sex_race_ethnicity_vars