A dataset of the ACS variable names used to calculate the Area Deprivation Index (ADI).
acs_varsA tibble with 138 rows and 8 variables:
ACS variable name
Brief description of the data the variable contains
Logical, indicating the variables to be used when calculating ADI using the 1- or 3-year estimates from 2011 and later or when using the 5-year estimates from 2012 or later
Logical, indicating the variables to be used when calculating ADI at the block group level using the 2015 or 2016 estimates
Logical, indicating the variables to be used when calculating ADI using the 2011 5-year estimates
Logical, indicating the variables to be used when calculating ADI using the 2008-2010 1-year estimates or the 2010 3-year estimates
Logical, indicating the variables to be used when calculating ADI using the pre-2008 1-year estimates, the pre-2010 3-year estimates, or the pre-2011 5-year estimates
Logical, indicating the
variables to use in conjunction with the few actual 2010 decennial census
variables when running get_adi(year = 2010, dataset =
"decennial")