- geography
A character string denoting the level of US census geography
at which you want to create a synthetic population. Required.
- state
A character string specifying states whose population you want
to synthesize. Defaults to NULL. Can contain full state names, two-letter
state abbreviations, or a two-digit FIPS code/GEOID (must be a vector of
strings, so use quotation marks and leading zeros if necessary). Must be
left as NULL if using the geoid or zcta parameter.
- county
A vector of character strings specifying the counties whose
population you want to synthesize. Defaults to NULL. If not NULL, the
state parameter must have a length of 1. County names and three-digit
FIPS codes are accepted (must contain strings, so use quotation marks and
leading zeros if necessary). Must be blank if using the geoid parameter.
- geoid
A character vector of GEOIDs (use quotation marks and leading
zeros). Defaults to NULL. Must be blank if state, county, or zcta
is used. Can contain different levels of geography (see details).
- zcta
A character vector of ZCTAs or the leading digit(s) of ZCTAs (use
quotation marks and leading zeros). Defaults to NULL. Must be blank if
state, county, or geoid is used.
Strings under 5 digits long will yield all ZCTAs that begin with those
digits.
Requires that geography = "zcta". If geography = "zcta" and zcta = NULL, all ZCTAs in the US will be used.
- year, dataset
Specifies the US Census data set on which to base the
demographic profile of your synthetic population.
year must be a single integer specifying the year of US Census data to
use.The data set used to calculate ADIs and ADI-3s.
dataset must be one of c("acs5", "acs3", "acs1", "decennial"), denoting
the 5-, 3-, and 1-year ACS along with the decennial census. Defaults to
"acs5".
When dataset = "decennial", year must be in c(1990, 2000, 2010).
Important: data are not always available depending on the level of
geography and data set chosen. See
https://www.census.gov/programs-surveys/acs/guidance/estimates.html.
- geometry
Logical value indicating whether or not shapefile data should
be included in the result, making the result an sf object
instead of a plain tibble. Defaults to FALSE.
The shapefile data that is returned is somewhat customizable by passing
certain arguments along to the tidycensus functions via ....
- cache_tables
The plural version of the cache_table argument in
tidycensus::get_acs() or tidycensus::get_decennial(). (get_adi()
calls the necessary tidycensus function many times in order to return
ADIs and ADI-3s, so many tables are cached if TRUE). Defaults to TRUE.
- max_age
A single integer representing the largest possible age that
can appear in the data set. Simulated age values exceeding this value will
be top-coded to this value. Defaults to 115. See details.
- rate
A single number, passed to stats::rexp() when synthesizing the
ages of the highest age bracket. Defaults to 0.25. See details.
- key
Your Census API key as a character string. Obtain one at
http://api.census.gov/data/key_signup.html. Defaults to NULL. Not
necessary if you have already loaded your key with census_api_key().
- seed
Passed onto set.seed(), which is called before
probabilistically synthesizing the age values with sample().
- ...
Additional arguments to be passed onto tidycensus::get_acs() or
tidycensus::get_decennial(). These must all be named. Must not match any
of the tidycensus formal arguments that sociome needs to set
explicitly.
This may be found to be helpful when setting geometry = TRUE, since the
tidycensus functions pass ... onto the appropriate tigris function
(namely, one of tigris::states(), tigris::counties(),
tigris::tracts(), tigris::block_groups(), or tigris::zctas(),
according to the the value of geography). This enables the user to
somewhat customize the shapefile data obtained.